@@ -3,9 +3,10 @@ from flask import Flask, request, current_app
 from google.protobuf.json_format import MessageToJson
 
 import json
+import io
 
-
-from porerefiner.cli_utils import server, load_from_csv
+from porerefiner.cli_utils import server
+from porerefiner.samplesheets import load_from_csv
 from porerefiner.protocols.porerefiner.rpc.porerefiner_pb2 import RunRequest, RunListRequest, RunAttachRequest, RunRsyncRequest
 
 from porerefiner.app import app
@@ -18,7 +19,8 @@ def attach_to_run(run_id=None):
     if not run_id:
         run_id = request.form.get('run_id', None)
     file = request.files.get('sample_sheet')
-    message = load_from_csv(file)
+    buff = io.StringIO(file.read().decode('utf-8'))
+    message = load_from_csv(buff)
     async def attach_runner(run_id, message):
         with server(current_app.config['config_file']) as serv:
             return await serv.AttachSheetToRun(RunAttachRequest(name=run_id, sheet=message))
