@@ -143,13 +143,13 @@ def paths(draw, under="", min_deep=2, max_deep=None, pathlib_only=False):
 Event = namedtuple('Event', ('src_path', 'is_directory'))
 
 @composite
-def fsevents(draw, min_deep=4, isDirectory=None):
+def fsevents(draw, min_deep=4, isDirectory=None, src_path=None):
     if isDirectory is None:
         is_dir = booleans()
     else:
         is_dir = just(bool(isDirectory))
     return draw(builds(Event,
-                       src_path=paths(min_deep=min_deep, pathlib_only=True),
+                       src_path=src_path or paths(min_deep=min_deep, pathlib_only=True),
                        is_directory=is_dir))
 
 def random_name_subclass(of=object, **classdef):
@@ -159,6 +159,10 @@ def random_name_subclass(of=object, **classdef):
     globals()[new_typename] = new_type
     return new_type
 
+@composite
+def names(draw):
+    return draw(builds(namesgenerator.get_random_name))
+
 class TestSubmitter(jobs.submitters.Submitter):
     async def test_noop(*a, **k):
         return None
@@ -167,8 +171,8 @@ class TestSubmitter(jobs.submitters.Submitter):
     async def begin_job(*a, **k):
         return "fake started"
     async def poll_job(*a, **k):
-        return "fake status"
-    def closeout_job(*a, **k):
+        return False
+    async def closeout_job(*a, **k):
         return None
 
 @composite
@@ -189,10 +193,8 @@ def submitters(draw):
 
 class TestJob(jobs.RunJob):
 
-    def setup(*a, **k):
-        return "", {}
-    def collect(*a, **k):
-        return None
+    def run(*a, **k):
+        yield "", {}
 
 @composite
 def jobs(draw):
@@ -207,49 +209,7 @@ def jobs(draw):
 #     return draw(builds(models.Job,
 #                        job_state=state))
 
-class Model:
-
-    
-
-    @staticmethod
-    @composite
-    def Runs(draw, sheet=True):
-        if sheet:
-            ss = Model.Samplesheets()
-        else:
-            ss = just(None)
-        path = draw(paths(pathlib_only=True))
-        return draw(builds(models.Run,
-                        #pk=sql_ints(),
-                        # flowcell=flowcells(path=path.parent),
-                        _sample_sheets=ss,
-                        name=text(),
-                        library_id=text(),
-                        run_id=text(),
-                        started=datetimes(max_value=the_present),
-                        ended=datetimes(min_value=the_present),
-                        status=sampled_from([status[0] for status in models.Run.statuses]),
-                        path=just(path),
-                        basecalling_model=sampled_from([model[0] for model in models.Run.basecallers])))
-
-    @staticmethod
-    @composite
-    def Jobs(draw, state=jobs()):
-        TestJob(TestSubmitter())
-        return draw(builds(models.Job,
-                       job_class=just(TestJob.__name__),
-                       datadir=just("/dev/null")))
-
-    @staticmethod
-    @composite
-    def Files(draw, real=False):
-        if real:
-            path = builds(Path, builds(lambda *a, **k: tempfile.NamedTemporaryFile().name))
-        else:
-            path = paths(pathlib_only=True)
-        return draw(builds(models.File,
-                        pk=sql_ints(),
-                        path=path))
+class Message:
 
     @staticmethod
     @composite
@@ -278,7 +238,7 @@ class Model:
         lib = text(min_size=12, max_size=12)
         seq = text(min_size=12, max_size=12)
         bar = lists(text(min_size=12, max_size=12), min_size=0, max_size=3)
-        sam = lists(Model.Samples(), min_size=1, max_size=12)
+        sam = lists(Message.Samples(), min_size=1, max_size=12)
         ss = draw(builds(messages.SampleSheet,
                         porerefiner_ver=ver,
                         library_id=lib,
@@ -288,6 +248,79 @@ class Model:
         ss.date.FromDatetime(draw(dat))
         return ss
 
+class Model:
+
+    
+
+    @staticmethod
+    @composite
+    def Runs(draw, sheet=True):
+        if sheet:
+            ss = Model.Samplesheets()
+        else:
+            ss = just(None)
+        path = draw(paths(pathlib_only=True))
+        return draw(builds(models.Run,
+                        #pk=sql_ints(),
+                        # flowcell=flowcells(path=path.parent),
+                        _sample_sheets=ss,
+                        name=text(),
+                        library_id=text(),
+                        run_id=text(),
+                        started=datetimes(max_value=the_present),
+                        ended=datetimes(min_value=the_present),
+                        status=sampled_from([status[0] for status in models.Run.statuses]),
+                        path=just(path),
+                        basecalling_model=sampled_from([model[0] for model in models.Run.basecallers])))
+
+    @staticmethod
+    @composite
+    def Duties(draw, state=jobs()):
+        TestJob(TestSubmitter())
+        return draw(builds(models.Duty,
+                       job_class=just(TestJob.__name__),
+                       datadir=just("/dev/null")))
+
+    @staticmethod
+    @composite
+    def Files(draw, real=False, arg_path=None):
+        if real:
+            path = builds(Path, builds(lambda *a, **k: tempfile.NamedTemporaryFile().name))
+        else:
+            path = paths(pathlib_only=True)
+        return draw(builds(models.File,
+                        path=arg_path or path))
+
+    @staticmethod
+    @composite
+    def Samples(draw):
+        sid = text(min_size=7, max_size=10)
+        acc = text(min_size=5, max_size=10)
+        bar = text(min_size=10, max_size=10)
+        org = text(min_size=12, max_size=12)
+        ext = text(min_size=10, max_size=10)
+        com = text()
+        use = emails()
+        return draw(builds(models.Sample,
+                        sample_id=sid,
+                        accession=acc,
+                        barcode_id=bar,
+                        organism=org,
+                        extraction_kit=ext,
+                        comment=com,
+                        user=use))
+
+    @staticmethod
+    @composite
+    def Samplesheets(draw):
+        seq = text(min_size=12, max_size=12)
+        bar = lists(text(min_size=12, max_size=12), min_size=0, max_size=3)
+        ss = draw(builds(models.SampleSheet,
+                        sequencing_kit=seq,
+                        barcode_kit=bar,
+                        path=paths()))
+        return ss
+
     @staticmethod
     @composite
     def Flowcells(draw, path=None):
@@ -300,11 +333,29 @@ class Model:
         else:
             pat = just(Path(path))
         return draw(builds(models.Flowcell,
-                        #pk=pk,
-                        consumable_id=cid,
-                        consumable_name=cname,
-                        consumable_type=cty,
-                        path=pat))
+                            consumable_id=cid,
+                            consumable_name=cname,
+                            consumable_type=cty,
+                            path=pat))
+
+    @staticmethod
+    @composite
+    def Qas(draw):
+        return draw(builds(models.Qa,
+                           coverage=floats(),
+                           quality=floats()))
+
+
+@composite
+def file_events(draw):
+    "strategy to produce synchronized files and events"
+    path = builds(Path, just(tempfile.NamedTemporaryFile().name))
+    return draw(tuples(
+                       Model.Files(arg_path=path),
+                       fsevents(src_path=path, isDirectory=False)
+                       )
+    )
+
 
 class TestBase(TestCase):
 
